#!/bin/bash
. /usr/share/eole/FonctionsEoleNg
. /usr/bin/ParseDico

MDIR="/usr/share/era/modeles"
EOLE_DIR="/var/lib/eole"
REGLES_CSV="/var/lib/eole/config/regles.csv"

## existance du fichier xml firewall
if [ ! -e $MDIR/${type_amon}.xml ]
then
    EchoRouge "!! Modèle ${type_amon}.xml non trouvé !!"
    exit 1
fi

# script de lancement du compilateur de regle (backend) era
export PYTHONPATH="/usr/share/:/usr/share/eole/:$PYTHONPATH"
cd /usr/share/era/

## verifions en tout premier lieu que le firewall est bien prevu pour l'authentification
if [ $activer_nufw = "non"  ]
then
    if [ "`./backend/is_authenticated $MDIR/${type_amon}.xml`" = "True"  ]
    then
        EchoRouge "!! ATTENTION: le modele era est authentifiant alors que le pare-feu n'est pas defini comme etant authentifiant !!"
        exit 1
    fi
fi

#support des regles eole-firewall
/usr/share/eole/bastion/bin/bastion
if [ $? -eq 1 ]; then
    EchoRouge "!! Erreur a la generation des regles eole-firewall !!"
    exit 1
fi

./backend/compiler -o ${EOLE_DIR}/firewall.tmpl -a /usr/share/era/backend/data/active_tags -d ${REGLES_CSV} -t ${EOLE_DIR}/regles.tmpl $MDIR/${type_amon}.xml
if [ $? -eq 1 ]; then
    EchoRouge "!! Erreur lors de la generation des regles iptables par era !!"
    exit 1
fi

# compilation du fichier de règles optionnelles si nécessaire
grep -q "%" ${EOLE_DIR}/regles.tmpl
if [ $? -eq 0 ];then
    /usr/share/creole/creolecat.py -o ${REGLES_CSV} -i /etc/eole/config.eol ${EOLE_DIR}/regles.tmpl
else
    /bin/cp -f ${EOLE_DIR}/regles.tmpl ${REGLES_CSV}
fi

## gestion de la qos
./backend/qos_era_externe $MDIR/${type_amon}.xml

## authentification nufw
# instanciation "manuelle" du script de firewall
/usr/share/creole/creolecat.py  -o /sbin/lance.firewall -i /etc/eole/config.eol ${EOLE_DIR}/firewall.tmpl

## horaires de nuit du pare-feu
/usr/share/era/backend/horaires_firewall -i /var/lib/eole/config/horaires.txt >> /sbin/lance.firewall

# Instanciation manuelle du modele Era :
tmp_xml=$(mktemp)
/usr/share/creole/creolecat.py  -o $tmp_xml -i /etc/eole/config.eol /usr/share/era/modeles/"$type_amon".xml

# attribution des droits au fichier lance.firewall
chmod 700 /sbin/lance.firewall

# lancement du script iptables
/sbin/lance.firewall 2>&1 | head -n 2

# script de generation d'ACL NuFW :
if [ $activer_nufw = "oui" ]; then
    if [ ! -f /etc/nufw/acls.nufw ]; then
      # si pas de fichier la première fois, on le crée
      # pour comparaison avec le fichier généré
      touch /etc/nufw/acls.nufw
    fi
    cp /etc/nufw/acls.nufw /etc/nufw/acls.nufw.bak
    ./backend/nufw_acl_plaintext -o /etc/nufw/acls.nufw $tmp_xml
    [ ! $? = 0 ] && EchoRouge "Probleme pendant la generation des directives nufw" && rm $tmp_xml && exit 1
    rm $tmp_xml
    pgrep nuauth > /dev/null
    if [ ! $? = 0 ]; then
        /etc/init.d/nuauth start
    else
        cmp /etc/nufw/acls.nufw /etc/nufw/acls.nufw.bak >/dev/null 2>&1 || /etc/init.d/nuauth restart
    fi
fi

# ajout des règles pour les postes clients interdits
python /usr/share/era/postes_interdits.py

